@@ -3,14 +3,10 @@ from __future__ import annotations
 import logging
 import os
 import re
-from pathlib import Path
 
-import aiofiles
-import psutil as psutil
 import rich
 from yarl import URL
 
-from cyberdrop_dl.base_functions.data_classes import MediaItem
 from cyberdrop_dl.base_functions.error_classes import NoExtensionFailure
 
 FILE_FORMATS = {
@@ -48,49 +44,6 @@ async def log(text, quiet=False) -> None:
         rich.print(str(text))
 
 
-async def regex_links(urls: list) -> list:
-    """Regex grab the links from the URLs.txt file"""
-    """This allows code blocks or full paragraphs to be copy and pasted into the URLs.txt"""
-    yarl_links = []
-    for line in urls:
-        if line.lstrip().startswith('#'):
-            continue
-
-        all_links = [x.group().replace(".md.", ".") for x in re.finditer(
-            r"(?:http.*?)(?=($|\n|\r\n|\r|\s|\"|\[/URL]|]\[|\[/img]))", line)]
-        for link in all_links:
-            yarl_links.append(URL(link))
-    return yarl_links
-
-
-async def check_free_space(required_space: int, download_directory: Path) -> bool:
-    """Checks if there is enough free space on the drive to continue operating"""
-    free_space = psutil.disk_usage(str(download_directory.parent)).free
-    free_space = ((free_space / 1024) / 1024) / 1024
-    if required_space > free_space:
-        return False
-    else:
-        return True
-
-
-async def allowed_filetype(media: MediaItem, block_images: bool, block_video: bool, block_audio: bool, block_other: bool):
-    """Checks whether the enclosed file is allowed to be downloaded"""
-    ext = media.ext
-    if block_images:
-        if ext in FILE_FORMATS["Images"]:
-            return False
-    if block_video:
-        if ext in FILE_FORMATS["Videos"]:
-            return False
-    if block_audio:
-        if ext in FILE_FORMATS["Audio"]:
-            return False
-    if block_other:
-        if ext not in FILE_FORMATS["Images"] and ext not in FILE_FORMATS["Videos"] and ext not in FILE_FORMATS["Audio"]:
-            return False
-    return True
-
-
 async def purge_dir(dirname) -> None:
     """Purges empty directories"""
     deleted = []
@@ -104,13 +57,6 @@ async def purge_dir(dirname) -> None:
     list(map(os.rmdir, deleted))
 
 
-async def write_last_post_file(file: Path, url: str):
-    """Writes the last post url from a thread to the specified file"""
-    async with aiofiles.open(file, mode='a') as f:
-        await f.write(url + '\n')
-    return
-
-
 async def get_db_path(url: URL, referer=None):
     """Gets the URL path to be put into the DB and checked from the DB"""
     url_path = url.path
