@@ -296,8 +296,10 @@ class Downloader:
                         self.current_attempt.pop(url_path)
                     await self.output_failed(media, e)
                     return
-                if e.code == HTTPStatus.SERVICE_UNAVAILABLE:
+                if e.code == HTTPStatus.SERVICE_UNAVAILABLE or e.code == 521:
                     if hasattr(e, "message"):
+                        if not e.message:
+                            e.message = "Web server is down"
                         logging.debug(f"\n{media.url} ({e.message})")
                     await log(f"Failed Download: {media.filename}", quiet=True)
                     overall_file_progress.advance(self.files.failed_files_task_id, 1)
